/*
 * file CcHyperlinkType.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 * com.ibm.rational.wvcm.stp.cc.CcHyperlinkType
 *
 * (C) Copyright IBM Corporation 2004, 2011.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */
package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.Feedback;
import javax.wvcm.WvcmException;

/**
 * <p>
 * A proxy for a ClearCase hyperlink type.
 * </p>
 * <p>
 * After creating a hyperlink type, you can connect pairs of objects with hyperlinks of that type. 
 * Conceptually, a hyperlink is an arrow from one VOB-database object (version, branch, element, 
 * or VOB symbolic link) to another. To enable objects in two different VOBs to be connected, a 
 * hyperlink type with the same name must be created in both VOBs. For example, you create a hyperlink 
 * type named <b>design_spec</b>, for use in linking source code files to the associated design documents. 
 * Later, you can create a hyperlink of this type between <b>my_prog.c</b> and <b>my_prog.dsn</b>.
 * </p>
 * <p>
 * For more information about hyperlinks and hyperlink types, see the ClearCase "Guide to Managing Software Projects"
 * manual, and the cleartool man pages "mkhltype" and "mkhlink".
 * </p>
 * 
 */
public interface CcHyperlinkType extends CcTypeBase
{
    /**
     * <p>Create a new hyperlink type at the location identified by this proxy. The
     * location should be an object name selector specifying the hyperlink type's name
     * and the repository (VOB) in which to create it.
     * </p>
     * <p>Set the {@link CcTypeBase#SCOPE} property to specify the new type's global scope.
     * If no scope is set, a scope of NONE (ordinary scope) is used.
     * </p>
     * <p>Set the {@link CcTypeBase#HAS_SHARED_MASTERSHIP} property to <b>true</b> to allow
     * instances of this type to be created in any VOB replica.  If unspecified, the default
     * mastership is unshared.
     * </p>
    * @param flags Resource-specific creation flags.
     */
    public CcHyperlinkType doCreateCcHyperlinkType(TypeCreateFlag[] flags, Feedback feedback) throws WvcmException;
}
